@@ -19,10 +19,12 @@ Network-related utilities and helper functions.
 
 import logging
 import os
+import re
 import socket
 
 import netaddr
 import netifaces
+import six
 from six.moves.urllib import parse
 
 from oslo_utils._i18n import _
@@ -137,6 +139,22 @@ def is_valid_cidr(address):
     return True
 
 
+def is_valid_ipv6_cidr(address):
+    """Verify that address represents a valid IPv6 CIDR address.
+
+    :param address: address to verify
+    :type address: string
+    :returns: true if address is valid, false otherwise
+
+    .. versionadded:: 3.17
+    """
+    try:
+        netaddr.IPNetwork(address, version=6).cidr
+        return True
+    except (TypeError, netaddr.AddrFormatError):
+        return False
+
+
 def get_ipv6_addr_by_EUI64(prefix, mac):
     """Calculate IPv6 address using EUI-64 specification.
 
@@ -151,7 +169,7 @@ def get_ipv6_addr_by_EUI64(prefix, mac):
     .. versionadded:: 1.4
     """
     # Check if the prefix is an IPv4 address
-    if netaddr.valid_ipv4(prefix):
+    if is_valid_ipv4(prefix):
         msg = _("Unable to generate IP address by EUI64 for IPv4 prefix")
         raise ValueError(msg)
     try:
@@ -203,6 +221,22 @@ def is_valid_ip(address):
     return is_valid_ipv4(address) or is_valid_ipv6(address)
 
 
+def is_valid_mac(address):
+    """Verify the format of a MAC address.
+
+    Check if a MAC address is valid and contains six octets. Accepts
+    colon-separated format only.
+
+    :param address: MAC address to be validated.
+    :returns: True if valid. False if not.
+
+    .. versionadded:: 3.17
+    """
+    m = "[0-9a-f]{2}(:[0-9a-f]{2}){5}$"
+    return (isinstance(address, six.string_types) and
+            re.match(m, address.lower()))
+
+
 def _is_int_in_range(value, start, end):
     """Try to convert value to int and check if it lies within
     range 'start' to 'end'.
